from textual_autocomplete._autocomplete import AutoComplete
from textual.app import App, ComposeResult
from textual.containers import Center, VerticalScroll
from textual.widgets import Input


class CursorTracking(App[None]):
    CSS = """
    #scrollable {
        overflow: scroll scroll;
        scrollbar-color: red;
        Center {
            background: $accent;
            height: 100;
            width: 100;
            align-vertical: middle;
        }
        Input {
            width: 24;
        }
    }
    """

    def compose(self) -> ComposeResult:
        with VerticalScroll(id="scrollable", can_focus=False):
            with Center():
                input = Input(placeholder="Type here...")
                input.cursor_blink = False
                yield input

        yield AutoComplete(
            target=input,
            candidates=["foo", "bar", "baz", "qux", "boop"],
        )


if __name__ == "__main__":
    app = CursorTracking()
    app.run()



"""By default, textual-autocomplete replaces the entire content of a widget
with a completion.

Sometimes, however, you may wish to insert the completion text, or otherwise use
custom logic to determine the end-state of the Input after the user selects a completion.

For example, if completing a path on a filesystem, you may wish to offer partial completions
of the path based on the current content of the Input. Then, when the user selects a completion,
you could offer a different set of completions based on the new path in the Input.
"""

from pathlib import Path
from textual.app import App, ComposeResult
from textual.containers import Container
from textual.widgets import Input, Label

from textual_autocomplete import PathAutoComplete


class FileSystemPathCompletions(App[None]):
    CSS = """
    #container {
        padding: 2 4;
    }
    #label {
        margin-left: 3;
    }
    Input {
        width: 80%;
    }
    """

    def compose(self) -> ComposeResult:
        with Container(id="container"):
            yield Label("Choose a file!", id="label")
            input_widget = Input(placeholder="Enter a path...")
            yield input_widget
            yield PathAutoComplete(target=input_widget, path=Path.cwd())


if __name__ == "__main__":
    app = FileSystemPathCompletions()
    app.run()
